COMPMID-2160: Implement Round for NEON

Change-Id: Ie80e2ad294eaf95bc823d979842c320e8fb41f67
Signed-off-by: Usama Arif <usama.arif@arm.com>
Reviewed-on: https://review.mlplatform.org/c/1215
Comments-Addressed: Arm Jenkins <bsgcomp@arm.com>
Reviewed-by: Georgios Pinitas <georgios.pinitas@arm.com>
Tested-by: Arm Jenkins <bsgcomp@arm.com>
diff --git a/arm_compute/core/NEON/NEMath.h b/arm_compute/core/NEON/NEMath.h
index 5c60d73..46d97f6 100644
--- a/arm_compute/core/NEON/NEMath.h
+++ b/arm_compute/core/NEON/NEMath.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, 2017 ARM Limited.
+ * Copyright (c) 2016-2019 ARM Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -36,6 +36,14 @@
  */
 float32x4_t vfloorq_f32(float32x4_t val);
 
+/** Calculate round value of a vector to nearest with ties to even.
+ *
+ * @param[in] val Input vector value in F32 format.
+ *
+ * @return The calculated round vector.
+ */
+float32x4_t vroundq_rte_f32(float32x4_t val);
+
 /** Calculate inverse square root.
  *
  * @param[in] x Input value.
@@ -123,12 +131,20 @@
  *
  * @note We clamp x to [-5,5] to avoid overflowing issues.
  *
  * @param[in] val Input vector value in F32 format.
  *
  * @return The calculated Hyperbolic Tangent.
  */
 float16x8_t vtanhq_f16(float16x8_t val);
 
+/** Calculate round value of a vector to nearest with ties to even.
+ *
+ * @param[in] val Input vector value in F16 format.
+ *
+ * @return The calculated round vector.
+ */
+float16x8_t vroundq_rte_f16(float16x8_t val);
+
 /** Calculate reciprocal.
  *
  * @param[in] x Input value.
@@ -123,12 +131,20 @@
  * @note We clamp x to [-5,5] to avoid overflowing issues.
  *
- * @param[in] val Input vector value in F32 format.
+ * @param[in] val Input vector value in F16 format.
  *
  * @return The calculated Hyperbolic Tangent.